@@ -2,8 +2,8 @@
  **
  ** sngrep - SIP Messages flow viewer
  **
- ** Copyright (C) 2013-2016 Ivan Alonso (Kaian)
- ** Copyright (C) 2013-2016 Irontec SL. All rights reserved.
+ ** Copyright (C) 2013-2017 Ivan Alonso (Kaian)
+ ** Copyright (C) 2013-2017 Irontec SL. All rights reserved.
  **
  ** This program is free software: you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -169,6 +169,11 @@ capture_offline(const char *infile, const char *outfile)
         return 1;
     }
 
+    // Check if file is standard input
+    if (strlen(infile) == 1 && *infile == '-') {
+        infile = "/dev/stdin";
+    }
+
     // Set capture input file
     capinfo->infile = infile;
 
@@ -390,6 +395,17 @@ capture_packet_reasm_ip(capture_info_t *capinfo, const struct pcap_pkthdr *heade
         }
     }
 
+#ifdef SLL_HDR_LEN
+    if (capinfo->link == DLT_LINUX_SLL) {
+        struct sll_header *sll = (struct sll_header *) packet;
+        if (ntohs(sll->sll_protocol) == ETHERTYPE_8021Q) {
+            link_hl += 4;
+        }
+    }
+#endif
+
+
+
     // Get IP header
     ip4 = (struct ip *) (packet + link_hl);
 
@@ -588,6 +604,7 @@ capture_packet_reasm_tcp(capture_info_t *capinfo, packet_t *packet, struct tcphd
     memcpy(full_payload, pkt->payload, pkt->payload_len);
 
     // This packet is ready to be parsed
+    int original_size = pkt->payload_len;
     int valid = sip_validate_packet(pkt);
     if (valid == VALIDATE_COMPLETE_SIP) {
         // Full SIP packet!
@@ -598,9 +615,11 @@ capture_packet_reasm_tcp(capture_info_t *capinfo, packet_t *packet, struct tcphd
 
         // We have a full SIP Packet, but do not remove everything from the reasm queue
         packet_t *cont = packet_clone(pkt);
-        int pldiff = size_payload - pkt->payload_len;
-        packet_set_payload(cont, full_payload + pkt->payload_len, pldiff);
-        vector_append(capinfo->tcp_reasm, cont);
+        int pldiff = original_size - pkt->payload_len;
+        if (pldiff > 0 && pldiff < MAX_CAPTURE_LEN) {
+            packet_set_payload(cont, full_payload + pkt->payload_len, pldiff);
+            vector_append(capinfo->tcp_reasm, cont);
+        }
 
         // Return the full initial packet
         return pkt;
@@ -754,6 +773,11 @@ capture_close()
     if (vector_count(capture_cfg.sources) == 0)
         return;
 
+    // Close dump file
+    if (capture_cfg.pd) {
+        dump_close(capture_cfg.pd);
+    }
+
     // Stop all captures
     vector_iter_t it = vector_iterator(capture_cfg.sources);
     while ((capinfo = vector_iterator_next(&it))) {
@@ -761,14 +785,9 @@ capture_close()
         if (capinfo->handle) {
             pcap_breakloop(capinfo->handle);
             pthread_join(capinfo->capture_t, NULL);
-            pcap_close(capinfo->handle);
         }
     }
 
-    // Close dump file
-    if (capture_cfg.pd) {
-        dump_close(capture_cfg.pd);
-    }
 }
 
 int
@@ -781,6 +800,8 @@ capture_launch_thread(capture_info_t *capinfo)
     // Start all captures threads
     vector_iter_t it = vector_iterator(capture_cfg.sources);
     while ((capinfo = vector_iterator_next(&it))) {
+        // Mark capture as running
+        capinfo->running = true;
         if (pthread_create(&capinfo->capture_t, &attr, (void *) capture_thread, capinfo)) {
             return 1;
         }
@@ -797,7 +818,8 @@ capture_thread(void *info)
 
     // Parse available packets
     pcap_loop(capinfo->handle, -1, parse_packet, (u_char *) capinfo);
-
+    pcap_close(capinfo->handle);
+    capinfo->running = false;
 }
 
 int
@@ -812,6 +834,18 @@ capture_is_online()
     return 1;
 }
 
+int
+capture_is_running()
+{
+    capture_info_t *capinfo;
+    vector_iter_t it = vector_iterator(capture_cfg.sources);
+    while ((capinfo = vector_iterator_next(&it))) {
+        if (capinfo->running)
+            return 1;
+    }
+    return 0;
+}
+
 int
 capture_set_bpf_filter(const char *filter)
 {
@@ -871,6 +905,13 @@ capture_status_desc()
         }
     }
 
+#ifdef USE_EEP
+    // EEP Listen mode is always considered online
+    if (capture_eep_listen_port()) {
+        online++;
+    }
+#endif
+
     if (capture_paused()) {
         if (online > 0 && offline == 0) {
             return "Online (Paused)";
