@@ -2,8 +2,8 @@
  **
  ** sngrep - SIP Messages flow viewer
  **
- ** Copyright (C) 2013-2016 Ivan Alonso (Kaian)
- ** Copyright (C) 2013-2016 Irontec SL. All rights reserved.
+ ** Copyright (C) 2013-2017 Ivan Alonso (Kaian)
+ ** Copyright (C) 2013-2017 Irontec SL. All rights reserved.
  **
  ** This program is free software: you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -68,9 +68,14 @@ ncurses_init()
 {
     int bg, fg;
     const char *term;
+    FILE *fstdin;
+
     // Set Locale
     setlocale(LC_CTYPE, "");
 
+    // Allow reading from stdin
+    fstdin = freopen("/dev/tty", "r", stdin);
+
     // Initialize curses
     if (!initscr()) {
         fprintf(stderr, "Unable to initialize ncurses mode.\n");
@@ -346,7 +351,7 @@ int
 draw_message_pos(WINDOW *win, sip_msg_t *msg, int starting)
 {
     int height, width, line, column, i;
-    const char *cur_line, *payload;
+    const char *cur_line, *payload, *method = NULL;
     int syntax = setting_enabled(SETTING_SYNTAX);
 
     // Default text format
@@ -357,6 +362,11 @@ draw_message_pos(WINDOW *win, sip_msg_t *msg, int starting)
     // Get window of main panel
     getmaxyx(win, height, width);
 
+    // Get message method (if request)
+    if (msg_is_request(msg)) {
+        method = sip_method_str(msg->reqresp);
+    }
+
     // Get packet payload
     cur_line = payload = (const char *) msg_get_payload(msg);
 
@@ -377,7 +387,7 @@ draw_message_pos(WINDOW *win, sip_msg_t *msg, int starting)
                     attrs = A_BOLD | COLOR_PAIR(CP_RED_ON_DEF);
 
                 // SIP URI syntax
-                if (!strncasecmp(payload + i, "sip:", 4)) {
+                if (method && i == strlen(method) + 1) {
                     attrs = A_BOLD | COLOR_PAIR(CP_CYAN_ON_DEF);
                 }
             } else {
